import { world, system, ItemStack } from "@minecraft/server";
import { canCraft } from "./items.js"

function getSelected(player, items, result, amnt) {
  const inventory = player.getComponent("inventory").container;
  let hasAllItems = true;

  // Verifica se o jogador tem todos os itens necessários
  for (const { item, amount } of items) {
    let count = 0;

    // Soma os itens correspondentes no inventário
    for (let i = 0; i < inventory.size; i++) {
      const slotItem = inventory.getItem(i);
      if (slotItem && slotItem.typeId === item) { // Usando item diretamente, sem typeId
        count += slotItem.amount; // Soma a quantidade
      }
    }
    // Verifica se a quantidade total é menor do que a necessária
    if (count < amount) {
      hasAllItems = false;
      break;
    }
  }

  if (hasAllItems) {
    // Remover os itens necessários do inventário
    for (const { item, amount } of items) {
      let remaining = amount;

      for (let i = 0; i < inventory.size; i++) {
        const slotItem = inventory.getItem(i);
        if (slotItem && slotItem.typeId === item) {
          if (slotItem.amount > remaining) {
            slotItem.amount -= remaining;
            inventory.setItem(i, slotItem);
            break;
          } else {
            remaining -= slotItem.amount;
            inventory.setItem(i, null);
          }
        }
      }
    }

    // Adicionar o item de resultado
    const resultItem = new ItemStack(result, amnt); // Define o item e a quantidade
    inventory.addItem(resultItem);
    player.playSound("random.anvil_use")
    // player.sendMessage(`Você recebeu um ${result}!`);
  } else {
    player.playSound("mob.villager.haggle")
    player.sendMessage("§cYou do not have enough items to craft this.")
  }
}

system.afterEvents.scriptEventReceive.subscribe((event) => {
  world.getPlayers().forEach(player => {
    let craftable = canCraft.find(c => c.id === event.id);  // Encontrar o item craftável com base no evento
    if (craftable) {
      if (craftable.result.includes("_ammo")) {
        getSelected(player, craftable.requirements, craftable.result, 5);  // Chama a função para verificar o inventário
      } else {
        getSelected(player, craftable.requirements, craftable.result, 1)
      }
    } else {
      player.sendMessage("Este item não pode ser craftado!");  // Mensagem se o item não for encontrado
    }
  });
});